==> cristalise-kernel-5.2.0-sources.jar: org/cristalise/kernel/collection/AggregationVertexFactory.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.collection;

import org.cristalise.kernel.graph.model.GraphModelManager;
import org.cristalise.kernel.graph.model.GraphPoint;
import org.cristalise.kernel.graph.model.TypeNameAndConstructionInfo;
import org.cristalise.kernel.graph.model.VertexFactory;
import org.cristalise.kernel.utils.CastorHashMap;

/**
 * GraphModel vertex factory for AggregationMembers 
 *
 */
public class AggregationVertexFactory implements VertexFactory
{
    private Aggregation mAggregation = null;


    @Override
	public void setCreationContext(Object aggregation)
    {
        if (aggregation != null && aggregation instanceof Aggregation)
            mAggregation = (Aggregation)aggregation;
    }


    @Override
	public void create
    (
        GraphModelManager           graphModelManager,
        GraphPoint                       location,
        TypeNameAndConstructionInfo typeNameAndConstructionInfo
    ) throws Exception
    {
        if (typeNameAndConstructionInfo.mInfo.equals("AggregationMember")) {
            mAggregation.addMember(null, new CastorHashMap(), "",location, 40, 40);
        }
    }
}

==> cristalise-kernel-5.7.0-sources.jar: org/cristalise/kernel/collection/AggregationVertexFactory.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.collection;

import org.cristalise.kernel.graph.model.GraphModelManager;
import org.cristalise.kernel.graph.model.GraphPoint;
import org.cristalise.kernel.graph.model.TypeNameAndConstructionInfo;
import org.cristalise.kernel.graph.model.VertexFactory;
import org.cristalise.kernel.utils.CastorHashMap;

/**
 * GraphModel vertex factory for AggregationMembers 
 *
 */
public class AggregationVertexFactory implements VertexFactory
{
    private Aggregation mAggregation = null;


    @Override
	public void setCreationContext(Object aggregation)
    {
        if (aggregation != null && aggregation instanceof Aggregation)
            mAggregation = (Aggregation)aggregation;
    }


    @Override
	public void create(GraphModelManager graphModelManager, GraphPoint location, TypeNameAndConstructionInfo typeNameAndConstructionInfo)
	        throws Exception
    {
        if (typeNameAndConstructionInfo.mInfo.equals("AggregationMember")) {
            mAggregation.addMember(null, new CastorHashMap(), "",location, 40, 40, null);
        }
    }
}
